import * as React from 'react';
import React__default from 'react';

interface AccordionProps {
    children: React.ReactNode;
    className?: string;
    disabled?: boolean;
    onBlur?: (event: React.FocusEvent<HTMLButtonElement>) => void;
    onClick?: (event: React.MouseEvent<HTMLButtonElement>) => void;
    onChange?: (open: boolean) => void;
    onFocus?: (event: React.FocusEvent<HTMLButtonElement>) => void;
    onKeyDown?: (event: React.KeyboardEvent<HTMLButtonElement>) => void;
    open?: boolean;
    title: React.ReactNode;
}
declare type AccordionHandle = {
    button: React.MutableRefObject<HTMLButtonElement>['current'] | null;
    close: () => void;
    open: () => void;
};
declare const Accordion: React.ForwardRefExoticComponent<AccordionProps & React.RefAttributes<AccordionHandle>>;

interface AccordionGroupProps {
    children?: React.ReactNode;
}
declare const AccordionGroup: React.FC<AccordionGroupProps>;

declare type Crumb = {
    label: string;
    url: string;
};
interface BreadcrumbProps {
    className?: string;
    crumbs?: Crumb[];
    id?: string;
}
declare const Breadcrumb: React.FC<BreadcrumbProps>;

/**
 *
 */
declare type Color = 'primary' | 'secondary' | 'tertiary';
/**
 *
 */
declare type Size = 'large' | 'medium' | 'small';

/**
 * Component Prop Types
 *
 * Unions React.AllHTMLAttributes and React.AriaAttributes so that all components that use this
 * as their props interface.
 */
declare type AttributeType<HTMLElementType> = React__default.AllHTMLAttributes<HTMLElementType> & React__default.AriaAttributes;

declare type ButtonOmitProps = 'size';
interface ButtonProps extends Omit<AttributeType<HTMLButtonElement>, ButtonOmitProps> {
    /**
     * The color of the button.
     *
     * Default value: 'primary'
     */
    color?: Color | 'success' | 'error';
    /**
     * Makes the button take 100% of the parent's width.
     *
     * Default value: false
     */
    fullWidth?: boolean;
    /**
     * Adds a class to the button based on the size prop's value.
     *
     * Default value: 'medium'
     */
    size?: Size;
    /**
     * The behavior of the button when it is clicked in a form.
     *
     * Default value: 'button'
     */
    type?: 'button' | 'submit' | 'reset';
    /**
     * Controls the style of the button.
     *
     * Default value: 'filled'
     */
    variant?: 'filled' | 'outlined' | 'text';
}
/**
 * Styless Button Component
 *
 * The styless button component renders a button element. The button has a few
 * design system props that control how it renders. Color controls the theme
 * color of the button, size controls the size of the button, and variant controls
 * how it is rendered. The default color is 'primary', the default size is 'medium',
 * and the default variant is 'filled'. We also made the default value for prop 'button'.
 *
 * Usage:
 * <Button>
 *   Submit
 * </Button>
 */
declare const Button: React.ForwardRefExoticComponent<ButtonProps & React.RefAttributes<HTMLButtonElement>>;

interface CardProps extends AttributeType<HTMLDivElement> {
}
/**
 * Styless Card Component
 *
 * The styless card component renders an article element.
 *
 * Usage:
 * <Card>
 *   <Typography variant='h1'>
 *     Card Heading
 *   </Typography>
 *
 *   <Typography>
 *     Some card content.
 *   </Typography>
 *
 *   <Link href='/to/somewhere' aria-label='view more about the topic of this content'>
 *     View more
 *   </Link>
 * </Card>
 */
declare const Card: React.FC<CardProps>;

declare type CommonInputType = {
    disabled?: boolean;
    /**
    * A string representing the error text.
    */
    error?: string;
    /**
    * A string representing the hint text.
    */
    hint?: string;
    /**
    * A string representing the label text.
    */
    label: string;
    /**
    * The name of the input component.
    */
    name: string;
};

declare type OmittedInputProps$4 = 'label' | 'name';
interface InputProps extends Omit<AttributeType<HTMLInputElement>, OmittedInputProps$4>, CommonInputType {
    /**
     *
     */
    variant?: 'filled' | 'outlined';
}
/**
 * Styless Input Component
 *
 * The styless input component contains the label, input, hint, and error component. This
 * is to make input elements ada-compliant by default. The hint and error components will
 * only render if you provide a value for their respective props. The usage example below
 * shows how to use an input that will have a hint and error component.
 *
 * Usage:
 * <Input
 *   error='Please enter a valid first name.'
 *   hint='Joe Smith'
 *   label='First Name'
 * />
 */
declare const Input: React.ForwardRefExoticComponent<InputProps & React.RefAttributes<HTMLInputElement>>;

declare type OmittedInputProps$3 = 'type';
interface CheckboxProps extends Omit<InputProps, OmittedInputProps$3> {
}
declare const Checkbox: React.ForwardRefExoticComponent<CheckboxProps & React.RefAttributes<HTMLInputElement>>;

interface CodeProps {
    children?: string;
    /**
     * Adds a class to the component.
     */
    className?: string;
    /**
     * The icon used for the copy button.
     */
    copyIcon: React.ReactNode;
    /**
     * Adds an id to the component.
     */
    id: string;
    /**
     * The programming language used within this code block.
     */
    language?: string;
}
/**
 * Styless Code Component
 *
 * The styless code component renders a span that contains code within it
 * and a button for copying the code contained within that span.
 *
 * Usage:
 * <Code
 *   copyIcon={CopyIcon}
 *   id='my-code'
 * >
 *   {codeString}
 * </Code>
 */
declare const Code: React.FC<CodeProps>;

declare type OmittedInputProps$2 = 'type';
interface EmailProps extends Omit<InputProps, OmittedInputProps$2> {
}
declare const Email: React.ForwardRefExoticComponent<EmailProps & React.RefAttributes<HTMLInputElement>>;

interface ErrorProps {
    children?: React.ReactNode;
    id: string;
}
/**
 * Styless Error Component
 *
 * The styless error component renders a span element. The
 * error component is designed mainly for building out custom
 * input elements.
 */
declare const Error: React.FC<ErrorProps>;

interface FieldsetProps extends AttributeType<HTMLFieldSetElement> {
    legend: string;
}
/**
 * Styless Fieldset Component
 *
 * The fieldset component renders a fieldset, legend, and children
 * passed to it. The legend prop controls the legend text that is
 * rendered.
 *
 * Usage:
 * <Fieldset legend='Personal Information'>
 *   <Input label='First Name' hint='Allison' />
 *   <Input label='Last Name' hint='Smith' />
 *   <Email label='Email' hint='example@example.com' />
 * </Fieldset>
 */
declare const Fieldset: React.FC<FieldsetProps>;

interface HintProps {
    children?: React.ReactNode;
    id: string;
}
/**
 * Styless Hint Component
 *
 * The styless hint component renders a span element. The
 * hint component is designed mainly for building out custom
 * input elements.
 */
declare const Hint: React.FC<HintProps>;

declare type IconButtonPropsToOmit = 'aria-label' | 'children';
interface IconButtonProps extends Omit<ButtonProps, IconButtonPropsToOmit> {
    'aria-label': string;
    icon: React.ReactNode;
}
/**
 * Styless IconButton Component
 *
 * The icon button component renders our button component with icon rendering
 * capabilities. The icon is always rendered before the button text.
 *
 * Usage:
 * <IconButton icon={TrashIcon}>
 *   Delete
 * </IconButton>
 */
declare const IconButton: React.ForwardRefExoticComponent<IconButtonProps & React.RefAttributes<HTMLButtonElement>>;

interface ImageProps extends AttributeType<HTMLImageElement> {
    /**
     * A string containing a description of the image.
     */
    alt: string;
    /**
     * The height of the image.
     */
    height: number;
    /**
     * The URL for the image.
     */
    src: string;
    /**
     * The width of the image.
     */
    width: number;
}
/**
 * Styless Image Component
 *
 * The styless image component renders a figure, figcaption, and img element. The alt
 * prop for the Image component is used as the alt attribute value on the img element
 * and as the child for the figcaption element. The width and the height is provided
 * for core web vitals performance.
 *
 * Usage:
 * <Image alt='some alt text' src='https://my-img-url' />
 */
declare const Image: React.FC<ImageProps>;

interface LinkProps extends AttributeType<HTMLAnchorElement> {
    /**
     * A URL to navigate to.
     */
    href: string;
    /**
     * Controls the style of the link.
     *
     * Default value: 'link'
     */
    variant?: 'link' | 'button';
}
/**
 * Styless Link Component
 *
 * The link component renders an anchor element. The anchor element
 * has two variants associated with it: 'link' and 'button'. The link
 * variant is the default variant that will render.
 *
 * Usage:
 * <Link href='https://example.com'>
 *   Link Text
 * </Link>
 */
declare const Link: React.ForwardRefExoticComponent<LinkProps & React.RefAttributes<HTMLAnchorElement>>;

interface ListItemProps extends AttributeType<HTMLLIElement> {
}
/**
 * Styless ListItem Component
 *
 * The list item component renders a li element. Its only purpose is
 * to provide all of the components you need to use the UnorderedList
 * and OrderedList components.
 */
declare const ListItem: React.FC<ListItemProps>;

interface OrderedListProps extends AttributeType<HTMLOListElement> {
}
/**
 * Styless OrderedList Component
 *
 * The styless ordered list component renders a ol element.
 *
 * Usage:
 * <OrderedList>
 *   <ListItem>one</ListItem>
 *   ...more list items
 * </OrderedList>
 */
declare const OrderedList: React.FC<OrderedListProps>;

declare type OmittedInputProps$1 = 'type';
interface PasswordProps extends Omit<InputProps, OmittedInputProps$1> {
}
declare const Password: React.ForwardRefExoticComponent<PasswordProps & React.RefAttributes<HTMLInputElement>>;

declare type OmittedInputProps = 'type';
interface RadioProps extends Omit<InputProps, OmittedInputProps> {
}
declare const Radio: React.ForwardRefExoticComponent<RadioProps & React.RefAttributes<HTMLInputElement>>;

declare type TypographyElements = HTMLHeadingElement | HTMLParagraphElement;

interface TypographyProps extends AttributeType<TypographyElements> {
    /**
     * Controls the style of the link.
     *
     * Default value: 'p'
     */
    variant?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p';
}
/**
 * The typography component renders the correct element based off of
 * the variant prop's value.
 *
 * Usage:
 * <Typography variant='h1'>
 *   Main Heading
 * </Typography>
 *
 * <Typography>
 *   Body text.
 * </Typography>
 */
declare const Typography: React.FC<TypographyProps>;

interface UnorderedListProps extends AttributeType<HTMLUListElement> {
}
/**
 * Styless UnorderedList Component
 *
 * The styless unordered list component renders a ul element.
 *
 * Usage:
 * <OrderedList>
 *   <ListItem>one</ListItem>
 *   ...more list items
 * </OrderedList>
 */
declare const UnorderedList: React.FC<UnorderedListProps>;

declare type TextareaOmitProps = 'name';
interface TextareaProps extends Omit<AttributeType<HTMLTextAreaElement>, TextareaOmitProps> {
    /**
     * Makes the button non-interactive.
     *
     * Default value: false
     */
    disabled?: boolean;
    /**
     * A string representing the error text.
     */
    error?: string;
    /**
     * A string representing the hint text.
     */
    hint?: string;
    /**
     * A string representing the label text.
     */
    label: string;
    /**
     * The name of the textarea component.
     */
    name: string;
}

declare const getDocumentFromRef: <ElementType extends HTMLElement>(ref: React.MutableRefObject<ElementType>) => Document | undefined;

declare const getWindow: () => Window | undefined;

interface UseControlledProps<ValueType> {
    controlled: ValueType;
    default: ValueType;
    name: string;
    state?: string;
}
declare function useControlled<ValueType>({ controlled, default: defaultProp, name, state }: UseControlledProps<ValueType>): [ValueType, (newValue: ValueType) => void];

declare const useCreateBlurHandler: <ElementType>(disabled: boolean, onBlur?: ((event: React.FocusEvent<ElementType, Element>) => void) | undefined) => (event: React.FocusEvent<ElementType, Element>) => void;

declare const useCreateChangeHandler: <ElementType>(disabled: boolean, onChange?: ((event: React.ChangeEvent<ElementType>) => void) | undefined) => (event: React.ChangeEvent<ElementType>) => void;

declare const useCreateClickHandler: <ElementType>(disabled: boolean, onClick?: ((event: React.MouseEvent<ElementType, MouseEvent>) => void) | undefined) => (event: React.MouseEvent<ElementType, MouseEvent>) => void;

declare const useCreateFocusHandler: <ElementType>(disabled?: boolean, onFocus?: ((event: React.FocusEvent<ElementType, Element>) => void) | undefined) => (event: React.FocusEvent<ElementType, Element>) => void;

declare const useListFocusTrap: (listLength: number, returnFocus: () => void, escapeKeyCode?: string, firstKeyCode?: string, lastKeyCode?: string, nextKeyCode?: string, previousKeyCode?: string) => {
    isTrapped: boolean;
    setIsTrapped: React.Dispatch<React.SetStateAction<boolean>>;
    focusIndex: number;
    setFocusIndex: React.Dispatch<React.SetStateAction<number>>;
    handleKeyDown: (event: React.KeyboardEvent) => void;
    previousFocusIndex: number;
    setPreviousFocusIndex: React.Dispatch<React.SetStateAction<number>>;
};

export { Accordion, AccordionGroup, AccordionGroupProps, AccordionHandle, AccordionProps, Breadcrumb, BreadcrumbProps, Button, ButtonProps, Card, CardProps, Checkbox, CheckboxProps, Code, CodeProps, Email, EmailProps, Error, ErrorProps, Fieldset, FieldsetProps, Hint, HintProps, IconButton, IconButtonProps, Image, ImageProps, Input, Link, LinkProps, ListItem, ListItemProps, OrderedList, OrderedListProps, Password, PasswordProps, Radio, RadioProps, TextareaProps, Typography, TypographyProps, UnorderedList, UnorderedListProps, getDocumentFromRef, getWindow, useControlled, useCreateBlurHandler, useCreateChangeHandler, useCreateClickHandler, useCreateFocusHandler, useListFocusTrap };
